#[repr(C)]pub struct OptionGreekValues {
pub delta: f64,
pub gamma: f64,
pub vega: f64,
pub theta: f64,
pub rho: f64,
}Expand description
Core option Greek sensitivity values (the 5 standard sensitivities). Designed as a composable building block embedded in all Greeks-carrying types.
Fields
delta: f64gamma: f64vega: f64theta: f64rho: f64Trait Implementations
Sourceimpl Add for OptionGreekValues
impl Add for OptionGreekValues
Sourceimpl Clone for OptionGreekValues
impl Clone for OptionGreekValues
Sourcefn clone(&self) -> OptionGreekValues
fn clone(&self) -> OptionGreekValues
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OptionGreekValues
impl Debug for OptionGreekValues
Sourceimpl Default for OptionGreekValues
impl Default for OptionGreekValues
Sourcefn default() -> OptionGreekValues
fn default() -> OptionGreekValues
Returns the “default value” for a type. Read more
Sourceimpl Display for OptionGreekValues
impl Display for OptionGreekValues
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for OptionGreekValueswhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for OptionGreekValueswhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for OptionGreekValues
impl<'py> IntoPyObject<'py> for OptionGreekValues
Sourcetype Target = OptionGreekValues
type Target = OptionGreekValues
The Python output type
Sourcetype Output = Bound<'py, <OptionGreekValues as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <OptionGreekValues as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl Mul<OptionGreekValues> for f64
impl Mul<OptionGreekValues> for f64
Sourcetype Output = OptionGreekValues
type Output = OptionGreekValues
The resulting type after applying the
* operator.Sourcefn mul(self, greeks: OptionGreekValues) -> OptionGreekValues
fn mul(self, greeks: OptionGreekValues) -> OptionGreekValues
Performs the
* operation. Read moreSourceimpl Mul<f64> for OptionGreekValues
impl Mul<f64> for OptionGreekValues
Sourceimpl PartialEq for OptionGreekValues
impl PartialEq for OptionGreekValues
Sourceimpl PartialOrd for OptionGreekValues
impl PartialOrd for OptionGreekValues
Sourceimpl PyClass for OptionGreekValues
impl PyClass for OptionGreekValues
Sourceimpl PyClassImpl for OptionGreekValues
impl PyClassImpl for OptionGreekValues
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Core option Greek sensitivity values (the 5 standard sensitivities).
/// Designed as a composable building block embedded in all Greeks-carrying types.
const RAW_DOC: &'static CStr = /// Core option Greek sensitivity values (the 5 standard sensitivities). /// Designed as a composable building block embedded in all Greeks-carrying types.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<OptionGreekValues as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<OptionGreekValues>
type Layout = <<OptionGreekValues as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<OptionGreekValues>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForOptionGreekValues
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyStubType for OptionGreekValues
impl PyStubType for OptionGreekValues
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
fn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for OptionGreekValues
impl PyTypeInfo for OptionGreekValues
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl Copy for OptionGreekValues
impl DerefToPyAny for OptionGreekValues
impl StructuralPartialEq for OptionGreekValues